==> zio-aws-robomaker_2.13-5.17.129.1-sources.jar: zio/aws/robomaker/model/SimulationJobBatchSummary.scala <==
package zio.aws.robomaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import zio.aws.robomaker.model.primitives.{
  Integer,
  CreatedAt,
  LastUpdatedAt,
  Arn
}
import scala.jdk.CollectionConverters._
final case class SimulationJobBatchSummary(
    arn: Option[Arn] = None,
    lastUpdatedAt: Option[LastUpdatedAt] = None,
    createdAt: Option[CreatedAt] = None,
    status: Option[zio.aws.robomaker.model.SimulationJobBatchStatus] = None,
    failedRequestCount: Option[Integer] = None,
    pendingRequestCount: Option[Integer] = None,
    createdRequestCount: Option[Integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.robomaker.model.SimulationJobBatchSummary = {
    import SimulationJobBatchSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.robomaker.model.SimulationJobBatchSummary
      .builder()
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .optionallyWith(
        lastUpdatedAt.map(value => LastUpdatedAt.unwrap(value): Instant)
      )(_.lastUpdatedAt)
      .optionallyWith(createdAt.map(value => CreatedAt.unwrap(value): Instant))(
        _.createdAt
      )
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        failedRequestCount.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.failedRequestCount)
      .optionallyWith(
        pendingRequestCount.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.pendingRequestCount)
      .optionallyWith(
        createdRequestCount.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.createdRequestCount)
      .build()
  }
  def asReadOnly: zio.aws.robomaker.model.SimulationJobBatchSummary.ReadOnly =
    zio.aws.robomaker.model.SimulationJobBatchSummary.wrap(buildAwsValue())
}
object SimulationJobBatchSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.robomaker.model.SimulationJobBatchSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.robomaker.model.SimulationJobBatchSummary =
      zio.aws.robomaker.model.SimulationJobBatchSummary(
        arn.map(value => value),
        lastUpdatedAt.map(value => value),
        createdAt.map(value => value),
        status.map(value => value),
        failedRequestCount.map(value => value),
        pendingRequestCount.map(value => value),
        createdRequestCount.map(value => value)
      )
    def arn: Option[Arn]
    def lastUpdatedAt: Option[LastUpdatedAt]
    def createdAt: Option[CreatedAt]
    def status: Option[zio.aws.robomaker.model.SimulationJobBatchStatus]
    def failedRequestCount: Option[Integer]
    def pendingRequestCount: Option[Integer]
    def createdRequestCount: Option[Integer]
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
    def getLastUpdatedAt: ZIO[Any, AwsError, LastUpdatedAt] =
      AwsError.unwrapOptionField("lastUpdatedAt", lastUpdatedAt)
    def getCreatedAt: ZIO[Any, AwsError, CreatedAt] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.robomaker.model.SimulationJobBatchStatus] =
      AwsError.unwrapOptionField("status", status)
    def getFailedRequestCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("failedRequestCount", failedRequestCount)
    def getPendingRequestCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("pendingRequestCount", pendingRequestCount)
    def getCreatedRequestCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("createdRequestCount", createdRequestCount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.robomaker.model.SimulationJobBatchSummary
  ) extends zio.aws.robomaker.model.SimulationJobBatchSummary.ReadOnly {
    override val arn: Option[Arn] = scala
      .Option(impl.arn())
      .map(value => zio.aws.robomaker.model.primitives.Arn(value))
    override val lastUpdatedAt: Option[LastUpdatedAt] = scala
      .Option(impl.lastUpdatedAt())
      .map(value => zio.aws.robomaker.model.primitives.LastUpdatedAt(value))
    override val createdAt: Option[CreatedAt] = scala
      .Option(impl.createdAt())
      .map(value => zio.aws.robomaker.model.primitives.CreatedAt(value))
    override val status
        : Option[zio.aws.robomaker.model.SimulationJobBatchStatus] = scala
      .Option(impl.status())
      .map(value =>
        zio.aws.robomaker.model.SimulationJobBatchStatus.wrap(value)
      )
    override val failedRequestCount: Option[Integer] = scala
      .Option(impl.failedRequestCount())
      .map(value => zio.aws.robomaker.model.primitives.Integer(value))
    override val pendingRequestCount: Option[Integer] = scala
      .Option(impl.pendingRequestCount())
      .map(value => zio.aws.robomaker.model.primitives.Integer(value))
    override val createdRequestCount: Option[Integer] = scala
      .Option(impl.createdRequestCount())
      .map(value => zio.aws.robomaker.model.primitives.Integer(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.robomaker.model.SimulationJobBatchSummary
  ): zio.aws.robomaker.model.SimulationJobBatchSummary.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-robomaker_2.13-5.17.130.8-sources.jar: zio/aws/robomaker/model/SimulationJobBatchSummary.scala <==
package zio.aws.robomaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import zio.aws.robomaker.model.primitives.{
  Integer,
  CreatedAt,
  LastUpdatedAt,
  Arn
}
import scala.jdk.CollectionConverters._
final case class SimulationJobBatchSummary(
    arn: Option[Arn] = None,
    lastUpdatedAt: Option[LastUpdatedAt] = None,
    createdAt: Option[CreatedAt] = None,
    status: Option[zio.aws.robomaker.model.SimulationJobBatchStatus] = None,
    failedRequestCount: Option[Integer] = None,
    pendingRequestCount: Option[Integer] = None,
    createdRequestCount: Option[Integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.robomaker.model.SimulationJobBatchSummary = {
    import SimulationJobBatchSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.robomaker.model.SimulationJobBatchSummary
      .builder()
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .optionallyWith(
        lastUpdatedAt.map(value => LastUpdatedAt.unwrap(value): Instant)
      )(_.lastUpdatedAt)
      .optionallyWith(createdAt.map(value => CreatedAt.unwrap(value): Instant))(
        _.createdAt
      )
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        failedRequestCount.map(value => value: java.lang.Integer)
      )(_.failedRequestCount)
      .optionallyWith(
        pendingRequestCount.map(value => value: java.lang.Integer)
      )(_.pendingRequestCount)
      .optionallyWith(
        createdRequestCount.map(value => value: java.lang.Integer)
      )(_.createdRequestCount)
      .build()
  }
  def asReadOnly: zio.aws.robomaker.model.SimulationJobBatchSummary.ReadOnly =
    zio.aws.robomaker.model.SimulationJobBatchSummary.wrap(buildAwsValue())
}
object SimulationJobBatchSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.robomaker.model.SimulationJobBatchSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.robomaker.model.SimulationJobBatchSummary =
      zio.aws.robomaker.model.SimulationJobBatchSummary(
        arn.map(value => value),
        lastUpdatedAt.map(value => value),
        createdAt.map(value => value),
        status.map(value => value),
        failedRequestCount.map(value => value),
        pendingRequestCount.map(value => value),
        createdRequestCount.map(value => value)
      )
    def arn: Option[Arn]
    def lastUpdatedAt: Option[LastUpdatedAt]
    def createdAt: Option[CreatedAt]
    def status: Option[zio.aws.robomaker.model.SimulationJobBatchStatus]
    def failedRequestCount: Option[Integer]
    def pendingRequestCount: Option[Integer]
    def createdRequestCount: Option[Integer]
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
    def getLastUpdatedAt: ZIO[Any, AwsError, LastUpdatedAt] =
      AwsError.unwrapOptionField("lastUpdatedAt", lastUpdatedAt)
    def getCreatedAt: ZIO[Any, AwsError, CreatedAt] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.robomaker.model.SimulationJobBatchStatus] =
      AwsError.unwrapOptionField("status", status)
    def getFailedRequestCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("failedRequestCount", failedRequestCount)
    def getPendingRequestCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("pendingRequestCount", pendingRequestCount)
    def getCreatedRequestCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("createdRequestCount", createdRequestCount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.robomaker.model.SimulationJobBatchSummary
  ) extends zio.aws.robomaker.model.SimulationJobBatchSummary.ReadOnly {
    override val arn: Option[Arn] = scala
      .Option(impl.arn())
      .map(value => zio.aws.robomaker.model.primitives.Arn(value))
    override val lastUpdatedAt: Option[LastUpdatedAt] = scala
      .Option(impl.lastUpdatedAt())
      .map(value => zio.aws.robomaker.model.primitives.LastUpdatedAt(value))
    override val createdAt: Option[CreatedAt] = scala
      .Option(impl.createdAt())
      .map(value => zio.aws.robomaker.model.primitives.CreatedAt(value))
    override val status
        : Option[zio.aws.robomaker.model.SimulationJobBatchStatus] = scala
      .Option(impl.status())
      .map(value =>
        zio.aws.robomaker.model.SimulationJobBatchStatus.wrap(value)
      )
    override val failedRequestCount: Option[Integer] =
      scala.Option(impl.failedRequestCount()).map(value => value: Integer)
    override val pendingRequestCount: Option[Integer] =
      scala.Option(impl.pendingRequestCount()).map(value => value: Integer)
    override val createdRequestCount: Option[Integer] =
      scala.Option(impl.createdRequestCount()).map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.robomaker.model.SimulationJobBatchSummary
  ): zio.aws.robomaker.model.SimulationJobBatchSummary.ReadOnly = new Wrapper(
    impl
  )
}
